Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(645)

Unified Diff: runtime/lib/double_patch.dart

Issue 1971193002: Patches to support Dart VM patch files in dart2js. (Closed) Base URL: sso://user/ahe/dart-sdk@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/lib/core_patch.dart ('k') | runtime/lib/errors_patch.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/lib/double_patch.dart
diff --git a/runtime/lib/double_patch.dart b/runtime/lib/double_patch.dart
index f33122ac763da4de7ff8611918fa8aa8d5c5a204..5a0c98fe5a9037e284fbc469f09ff47301a3acca 100644
--- a/runtime/lib/double_patch.dart
+++ b/runtime/lib/double_patch.dart
@@ -101,12 +101,12 @@ patch class double {
return _nativeParse(str, start, end);
}
- /* patch */ static double parse(String str,
- [double onError(String str)]) {
- var result = _parse(str);
+ /* patch */ static double parse(String source,
+ [double onError(String source)]) {
+ var result = _parse(source);
if (result == null) {
- if (onError == null) throw new FormatException("Invalid double", str);
- return onError(str);
+ if (onError == null) throw new FormatException("Invalid double", source);
+ return onError(source);
}
return result;
}
« no previous file with comments | « runtime/lib/core_patch.dart ('k') | runtime/lib/errors_patch.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698